@@ -10,6 +10,8 @@
 #include <osmocom/core/rate_ctr.h>
 #include <osmocom/core/select.h>
 #include <osmocom/core/stats.h>
+#include <osmocom/core/stat_item.h>
+#include <osmocom/gsm/gsm23003.h>
 
 #include <osmocom/crypt/auth.h>
 
@@ -54,6 +56,8 @@ enum gsm_auth_algo {
 	AUTH_ALGO_NONE,
 	AUTH_ALGO_XOR,
 	AUTH_ALGO_COMP128v1,
+	AUTH_ALGO_COMP128v2,
+	AUTH_ALGO_COMP128v3,
 };
 
 struct gsm_auth_info {
@@ -173,6 +177,10 @@ struct gsm_subscriber_connection {
 #define ROLE_BSC
 #include "gsm_data_shared.h"
 
+enum {
+	BTS_STAT_CHAN_LOAD_AVERAGE,
+	BTS_STAT_T3122,
+};
 
 enum {
 	BSC_CTR_CHREQ_TOTAL,
@@ -310,9 +318,8 @@ struct gsm_tz {
 };
 
 struct gsm_network {
-	/* global parameters */
-	uint16_t country_code;
-	uint16_t network_code;
+	struct osmo_plmn_id plmn;
+
 	char *name_long;
 	char *name_short;
 	enum gsm_auth_policy auth_policy;
@@ -370,6 +377,9 @@ struct gsm_network {
 	/* timer to expire old location updates */
 	struct osmo_timer_list subscr_expire_timer;
 
+	/* Timer for periodic channel load measurements to maintain each BTS's T3122. */
+	struct osmo_timer_list t3122_chan_load_timer;
+
 	/* Radio Resource Location Protocol (TS 04.31) */
 	struct {
 		enum rrlp_mode mode;
@@ -419,6 +429,16 @@ struct gsm_network {
 	struct llist_head *bsc_subscribers;
 };
 
+static inline const struct osmo_location_area_id *bts_lai(struct gsm_bts *bts)
+{
+	static struct osmo_location_area_id lai;
+	lai = (struct osmo_location_area_id){
+		.plmn = bts->network->plmn,
+		.lac = bts->location_area_code,
+	};
+	return &lai;
+}
+
 struct osmo_esme;
 
 enum gsm_sms_source_id {
@@ -558,7 +578,7 @@ enum bts_gprs_mode bts_gprs_mode_parse(const char *arg, int *valid);
 const char *bts_gprs_mode_name(enum bts_gprs_mode mode);
 int bts_gprs_mode_is_compat(struct gsm_bts *bts, enum bts_gprs_mode mode);
 
-int gsm48_ra_id_by_bts(uint8_t *buf, struct gsm_bts *bts);
+void gsm48_ra_id_by_bts(struct gsm48_ra_id *buf, struct gsm_bts *bts);
 void gprs_ra_id_by_bts(struct gprs_ra_id *raid, struct gsm_bts *bts);
 struct gsm_meas_rep *lchan_next_meas_rep(struct gsm_lchan *lchan);
 
