@@ -24,7 +24,7 @@
 #include <osmocom/gsm/lapdm.h>
 #endif
 
-#include <openbsc/common_cs.h>
+#include <openbsc/acc_ramp.h>
 
 /* 16 is the max. number of SI2quater messages according to 3GPP TS 44.018 Table 10.5.2.33b.1:
    4-bit index is used (2#1111 = 10#15) */
@@ -131,6 +131,7 @@ struct om2k_mo {
 	struct osmo_fsm_inst *fsm;
 };
 
+#define MAX_A5_KEY_LEN	(128/8)
 #define A38_XOR_MIN_KEY_LEN	12
 #define A38_XOR_MAX_KEY_LEN	16
 #define A38_COMP128_KEY_LEN	16
@@ -232,7 +233,11 @@ struct gsm_lchan {
 	uint8_t bs_power;
 	uint8_t ms_power;
 	/* Encryption information */
-	struct gsm_encr encr;
+	struct {
+		uint8_t alg_id;
+		uint8_t key_len;
+		uint8_t key[MAX_A5_KEY_LEN];
+	} encr;
 
 	/* AMR bits */
 	uint8_t mr_ms_lv[7];
@@ -671,6 +676,12 @@ struct bts_location {
 	double height;
 };
 
+/* Channel load counter */
+struct load_counter {
+	unsigned int total;
+	unsigned int used;
+};
+
 /* One BTS */
 struct gsm_bts {
 	/* list header in net->bts_list */
@@ -712,6 +723,8 @@ struct gsm_bts {
 	struct gsm_e1_subslot oml_e1_link;
 	uint8_t oml_tei;
 	struct e1inp_sign_link *oml_link;
+	/* when OML link was established */
+	time_t uptime;
 
 	/* Abis network management O&M handle */
 	struct abis_nm_h *nmh;
@@ -834,6 +847,9 @@ struct gsm_bts {
 	int force_combined_si;
 	int bcch_change_mark;
 
+	/* access control class ramping */
+	struct acc_ramp acc_ramp;
+
 #ifdef ROLE_BSC
 	/* Abis NM queue */
 	struct llist_head abis_queue;
@@ -872,6 +888,7 @@ struct gsm_bts {
 		} data;
 	} si_common;
 	bool early_classmark_allowed;
+	bool early_classmark_allowed_3g;
 	/* for testing only: Have an infinitely long radio link timeout */
 	bool infinite_radio_link_timeout;
 
@@ -895,6 +912,16 @@ struct gsm_bts {
 	char *pcu_sock_path;
 	struct pcu_sock_state *pcu_state;
 
+	struct osmo_stat_item_group *bts_statg;
+
+	/* BTS-specific overrides for timer values from struct gsm_network. */
+	uint8_t T3122;	/* ASSIGMENT REJECT wait indication */
+
+	/* Periodic channel load measurements are used to maintain T3122. */
+	struct load_counter chan_load_samples[7];
+	int chan_load_samples_idx;
+	uint8_t chan_load_avg; /* current channel load average in percent (0 - 100). */
+
 #endif /* ROLE_BSC */
 	void *role;
 };
