@@ -827,6 +827,12 @@ mgcp_header_done:
 		goto error2;
 	}
 
+	/* Apply Jiter buffer settings for this endpoint, they can be overriden by CRCX policy later */
+	endp->bts_use_jibuf = endp->cfg->bts_use_jibuf;
+	endp->bts_jitter_delay_min = endp->cfg->bts_jitter_delay_min;
+	endp->bts_jitter_delay_max = endp->cfg->bts_jitter_delay_max;
+
+
 	endp->allocated = 1;
 
 	/* set up RTP media parameters */
@@ -862,6 +868,13 @@ mgcp_header_done:
 		case MGCP_POLICY_DEFER:
 			/* stop processing */
 			create_transcoder(endp);
+			/* Set up jitter buffer if required after policy has updated jibuf endp values */
+			if (endp->bts_use_jibuf) {
+				endp->bts_jb = osmo_jibuf_alloc(tcfg->endpoints);
+				osmo_jibuf_set_min_delay(endp->bts_jb, endp->bts_jitter_delay_min);
+				osmo_jibuf_set_max_delay(endp->bts_jb, endp->bts_jitter_delay_max);
+				osmo_jibuf_set_dequeue_cb(endp->bts_jb, mgcp_dejitter_udp_send, &endp->net_end);
+			}
 			return NULL;
 			break;
 		case MGCP_POLICY_CONT:
@@ -870,6 +883,14 @@ mgcp_header_done:
 		}
 	}
 
+	/* Set up jitter buffer if required after policy has updated jibuf endp values */
+	if (endp->bts_use_jibuf) {
+		endp->bts_jb = osmo_jibuf_alloc(tcfg->endpoints);
+		osmo_jibuf_set_min_delay(endp->bts_jb, endp->bts_jitter_delay_min);
+		osmo_jibuf_set_max_delay(endp->bts_jb, endp->bts_jitter_delay_max);
+		osmo_jibuf_set_dequeue_cb(endp->bts_jb, mgcp_dejitter_udp_send, &endp->net_end);
+	}
+
 	LOGP(DMGCP, LOGL_DEBUG, "Creating endpoint on: 0x%x CI: %u port: %u/%u\n",
 		ENDPOINT_NUMBER(endp), endp->ci,
 		endp->net_end.local_port, endp->bts_end.local_port);
@@ -1333,6 +1354,9 @@ int mgcp_endpoints_allocate(struct mgcp_trunk_config *tcfg)
 void mgcp_release_endp(struct mgcp_endpoint *endp)
 {
 	LOGP(DMGCP, LOGL_DEBUG, "Releasing endpoint on: 0x%x\n", ENDPOINT_NUMBER(endp));
+	if (endp->bts_jb)
+		osmo_jibuf_delete(endp->bts_jb);
+	endp->bts_jb = NULL;
 	endp->ci = CI_UNUSED;
 	endp->allocated = 0;
 
@@ -1548,24 +1572,26 @@ void mgcp_format_stats(struct mgcp_endpoint *endp, char *msg, size_t size)
 	msg += nchars;
 	size -= nchars;
 
-	/* Error Counter */
-	nchars = snprintf(msg, size,
-			  "\r\nX-Osmo-CP: EC TIS=%u, TOS=%u, TIR=%u, TOR=%u",
-			  endp->net_state.in_stream.err_ts_counter,
-			  endp->net_state.out_stream.err_ts_counter,
-			  endp->bts_state.in_stream.err_ts_counter,
-			  endp->bts_state.out_stream.err_ts_counter);
-	if (nchars < 0 || nchars >= size)
-		goto truncate;
+	if (endp->cfg->osmux != OSMUX_USAGE_OFF) {
+		/* Error Counter */
+		nchars = snprintf(msg, size,
+				  "\r\nX-Osmo-CP: EC TIS=%u, TOS=%u, TIR=%u, TOR=%u",
+				  endp->net_state.in_stream.err_ts_counter,
+				  endp->net_state.out_stream.err_ts_counter,
+				  endp->bts_state.in_stream.err_ts_counter,
+				  endp->bts_state.out_stream.err_ts_counter);
+		if (nchars < 0 || nchars >= size)
+			goto truncate;
 
-	msg += nchars;
-	size -= nchars;
+		msg += nchars;
+		size -= nchars;
 
-	if (endp->osmux.state == OSMUX_STATE_ENABLED) {
-		snprintf(msg, size,
-			 "\r\nX-Osmux-ST: CR=%u, BR=%u",
-			 endp->osmux.stats.chunks,
-			 endp->osmux.stats.octets);
+		if (endp->osmux.state == OSMUX_STATE_ENABLED) {
+			snprintf(msg, size,
+				 "\r\nX-Osmux-ST: CR=%u, BR=%u",
+				 endp->osmux.stats.chunks,
+				 endp->osmux.stats.octets);
+		}
 	}
 truncate:
 	msg[size - 1] = '\0';
